@@ -22,6 +22,29 @@ WebService::Raygun::Message::Error::StackTrace - Encapsule the stacktrace in err
 
 =cut
 
+
+use Mouse::Util::TypeConstraints;
+
+subtype 'StackTrace' => as 'Object' =>
+  where { $_->isa('WebService::Raygun::Message::Error::StackTrace') };
+
+subtype 'ArrayOfStackTraces' => as 'ArrayRef[StackTrace]' => where {
+    scalar @{$_} >= 1 and defined $_->[0]->line_number;
+} => message {
+    return 'At least one stack trace element is required.';
+};
+
+coerce 'StackTrace' => from 'HashRef' => via {
+    return WebService::Raygun::Message::Error::StackTrace->new( %{$_} );
+};
+coerce 'ArrayOfStackTraces' => from 'ArrayRef[HashRef]' => via {
+    my $array_of_hashes = $_;
+    return [ map { WebService::Raygun::Message::Error::StackTrace->new( %{$_} ) }
+          @{$array_of_hashes} ];
+};
+
+no Mouse::Util::TypeConstraints;
+
 has line_number => (
     is      => 'rw',
     isa     => 'Int',
